==> nmrium-0.50.1.tgz: package/lib/component/panels/AutomaticAssignment/AutomaticAssignment.js <==
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { SvgNmrAssignment2 } from 'cheminfo-font';
import { FaBolt } from 'react-icons/fa';
import { isSpectrum1D } from '../../../data/data1d/Spectrum1D/isSpectrum1D';
import { useChartData } from '../../context/ChartContext';
import { tablePanelStyle } from '../extra/BasicPanelStyle';
import DefaultPanelHeader from '../header/DefaultPanelHeader';
import { SpectraAutomaticPickingButton } from '../header/SpectraAutomaticPickingButton';
import AutomaticAssignmentTable from './AutomaticAssignmentTable';
import { useAutoAssignments } from './useAutoAssignments';
function useCheckEnableAutomaticAssignments() {
    const { data } = useChartData();
    return data.some((spectrum) => {
        if (isSpectrum1D(spectrum)) {
            return spectrum?.ranges?.values.length > 0;
        }
        return spectrum?.zones?.values.length > 0;
    });
}
function AutomaticAssignment() {
    const { getAssignments, assignments, restAssignments } = useAutoAssignments();
    const enabled = useCheckEnableAutomaticAssignments();
    return (_jsxs("div", { css: tablePanelStyle, children: [_jsx(DefaultPanelHeader, { leftButtons: [
                    {
                        component: _jsx(SpectraAutomaticPickingButton, {}),
                    },
                    {
                        icon: _jsx(SvgNmrAssignment2, {}),
                        title: 'Automatic assignment',
                        onClick: getAssignments,
                        disabled: !enabled,
                    },
                    {
                        icon: _jsx(FaBolt, {}),
                        title: 'Reset assignment',
                        onClick: restAssignments,
                    },
                ] }), _jsx("div", { className: "inner-container", children: _jsx(AutomaticAssignmentTable, { data: assignments }) })] }));
}
export default AutomaticAssignment;

==> nmrium-0.55.0.tgz: package/lib/component/panels/AutomaticAssignment/AutomaticAssignment.js <==
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { SvgNmrAssignment2 } from 'cheminfo-font';
import { FaBolt } from 'react-icons/fa';
import { isSpectrum1D } from '../../../data/data1d/Spectrum1D/isSpectrum1D';
import { useChartData } from '../../context/ChartContext';
import { tablePanelStyle } from '../extra/BasicPanelStyle';
import DefaultPanelHeader from '../header/DefaultPanelHeader';
import { SpectraAutomaticPickingButton } from '../header/SpectraAutomaticPickingButton';
import AutomaticAssignmentTable from './AutomaticAssignmentTable';
import { useAutoAssignments } from './useAutoAssignments';
function useCheckEnableAutomaticAssignments() {
    const { data } = useChartData();
    return data.some((spectrum) => {
        if (isSpectrum1D(spectrum)) {
            return spectrum?.ranges?.values.length > 0;
        }
        return spectrum?.zones?.values.length > 0;
    });
}
function AutomaticAssignment() {
    const { getAssignments, assignments, restAssignments } = useAutoAssignments();
    const enabled = useCheckEnableAutomaticAssignments();
    return (_jsxs("div", { css: tablePanelStyle, children: [_jsx(DefaultPanelHeader, { leftButtons: [
                    {
                        component: _jsx(SpectraAutomaticPickingButton, {}),
                    },
                    {
                        icon: _jsx(SvgNmrAssignment2, {}),
                        tooltip: 'Automatic assignment',
                        onClick: getAssignments,
                        disabled: !enabled,
                    },
                    {
                        icon: _jsx(FaBolt, {}),
                        tooltip: 'Reset assignment',
                        onClick: restAssignments,
                    },
                ] }), _jsx("div", { className: "inner-container", children: _jsx(AutomaticAssignmentTable, { data: assignments }) })] }));
}
export default AutomaticAssignment;
